abacusai.agent_data_execution_result — AbacusAI documentation

# abacusai.agent_data_execution_result

## Classes

`AgentDataDocumentInfo` | Information for documents uploaded to agents.
`AbstractApiClass` |
`AgentDataExecutionResult` | Results of agent execution with uploaded data.

## Module Contents

class abacusai.agent_data_execution_result.AgentDataDocumentInfo(client, docId=None, filename=None, mimeType=None, size=None, pageCount=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Information for documents uploaded to agents.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - docId (str) – The docstore Document ID of the document.

    - filename (str) – The file name of the uploaded document.

    - mimeType (str) – The mime type of the uploaded document.

    - size (int) – The total size of the uploaded document.

    - pageCount (int) – The total number of pages in the uploaded document.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.agent_data_execution_result.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.agent_data_execution_result.AgentDataExecutionResult(client, response=None, deploymentConversationId=None, docInfos={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Results of agent execution with uploaded data.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - response (str) – The result of agent conversation execution.

    - deploymentConversationId (id) – The unique identifier of the deployment conversation.

    - docInfos (AgentDataDocumentInfo) – A list of dict containing information on documents uploaded to agent.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict